%global srcname ocrmypdf

Name:           %{srcname}
Version:        7.4.0
Release:        1%{?dist}
Summary:        Add an OCR text layer to scanned PDF files

# Main code: GPLv3; test files: all others
License:        GPLv3 and CC-BY-SA and Public Domain
URL:            https://github.com/jbarlow83/OCRmyPDF
Source0:        %{pypi_source}
# unpaper is still 0.3, probably due to later versions using ffmpeg.
Patch0001:      0001-Skip-tests-that-use-unpaper.patch

BuildArch:      noarch

BuildRequires:  ghostscript >= 9.15
BuildRequires:  pngquant >= 2.0.0
BuildRequires:  qpdf >= 8.1.0
BuildRequires:  tesseract >= 3.04
BuildRequires:  tesseract-osd
BuildRequires:  tesseract-langpack-fra
#BuildRequires:  unpaper >= 6.1
BuildRequires:  python3-devel
BuildRequires:  python3dist(cffi) >= 1.9.1
BuildRequires:  (python3dist(img2pdf) >= 0.3.0 with python3dist(img2pdf) < 0.4)
BuildRequires:  python3dist(pdfminer.six) = 20181108
BuildRequires:  python3dist(pikepdf) >= 0.9.1
BuildRequires:  python3dist(pillow) >= 4.0.0
BuildConflicts: python3dist(pillow) = 5.1.0
BuildRequires:  python3dist(pypdf2) >= 1.26.0
BuildRequires:  python3dist(pytest) >= 3.2
BuildRequires:  python3dist(pytest-cov)
BuildRequires:  python3dist(pytest-helpers-namespace)
BuildRequires:  python3dist(pytest-runner)
BuildRequires:  python3dist(pytest-xdist)
BuildRequires:  (python3dist(python-xmp-toolkit) >= 2 with python3dist(python-xmp-toolkit) < 3)
BuildRequires:  python3dist(reportlab) >= 3.3.0
BuildRequires:  python3dist(ruffus) >= 2.7.0
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  python3dist(setuptools-scm-git-archive)
BuildRequires:  python3dist(sphinx)

Requires:       ghostscript >= 9.15
Recommends:     pngquant >= 2.0.0
Requires:       qpdf >= 8.1.0
Requires:       tesseract >= 3.04
#Recommends:     unpaper >= 6.1
%{?python_enable_dependency_generator}

%description
OCRmyPDF adds an OCR text layer to scanned PDF files, allowing them to be
searched or copy-pasted.


%package -n %{srcname}-doc
Summary:        ocrmypdf documentation
License:        CC-BY-SA

%description -n %{srcname}-doc
Documentation for ocrmypdf


%prep
%autosetup -n %{srcname}-%{version} -p1

# Remove bundled egg-info
rm -rf src/%{srcname}.egg-info

# Remove workaround for https://github.com/jbarlow83/OCRmyPDF/issues/326
# Our pdfminer.six package correctly depends on chardet.
sed -i -e '/chardet/d' setup.py

# We don't build docs against the installed version, so force the version.
sed -i -e "s/from ocrmypdf import __version__ as OCRMYPDF_VERSION/OCRMYPDF_VERSION = '%{version}'/g" docs/conf.py

# Cleanup shebang and executable bits.
for f in src/%{srcname}/*.py src/%{srcname}/lib/*.py; do
    sed -e '1{\@^#!/usr/bin/env python@d}' $f > $f.new &&
    touch -r $f $f.new &&
    mv $f.new $f
    chmod -x $f
done


%build
%py3_build

# generate html docs
PYTHONPATH=${PWD}/build/lib sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}


%install
%py3_install


%check
PATH=%{buildroot}%{_bindir}:$PATH \
PYTHONDONTWRITEBYTECODE=1 \
PYTHONPATH=%{buildroot}%{python3_sitelib} \
    %{__python3} -m pytest -ra


%files -n %{srcname}
%doc README.rst tests/resources/README.rst
%license LICENSE
%{_bindir}/ocrmypdf
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}-py?.?.egg-info

%files -n %{srcname}-doc
%doc html
%license LICENSE


%changelog
* Sun Jan 13 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.4.0-1
- Update to latest version

* Sun Oct 14 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.2.1-1
- Update to latest version

* Tue Sep 25 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.1.0-1
- Update to latest version

* Fri Sep 21 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.0.6-1
- Update to latest version

* Sat Aug 25 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.0.4-1
- Update to latest version

* Thu Aug 23 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.0.3-2
- Remove extraneous shebangs
- Fix summary line
- Remove workaround for reportlab packaging bug

* Wed Aug 22 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 7.0.3-1
- Initial package.
